==> flx_ui-2.5.2.tar.gz: lib/widgets/deep_card/views/deep_card_view.dart <==
import 'package:flx_ui/flx_ui.dart';

class DeepCard extends StatelessWidget {
  final double? width;
  final double? height;

  final Color? color;

  final double? borderRadius;

  final bool clipped;

  final Widget child;

  const DeepCard({
    Key? key,
    this.width,
    this.height,
    this.color,
    this.clipped = false,
    this.borderRadius,
    required this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var inBorderRadius = (borderRadius ?? 12);
    var inColor = color ?? ColorTheme.primary(context);

    return clipped
        ? ClipRRect(
            borderRadius: BorderRadius.circular(inBorderRadius),
            child: _buildAll(inBorderRadius, inColor),
          )
        : _buildAll(inBorderRadius, inColor);
  }

  Container _buildAll(double inBorderRadius, Color inColor) {
    return Container(
      width: width,
      height: height,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(inBorderRadius),
        color: inColor,
        boxShadow: [
          BoxShadow(
            spreadRadius: -1,
            blurRadius: 3,
            color: Colors.black.withAlpha(50),
          ),
          BoxShadow(
            spreadRadius: -2,
            blurRadius: 5,
            color: Colors.black.withAlpha(20),
          ),
          BoxShadow(
            spreadRadius: -4,
            blurRadius: 8,
            offset: Offset(0, 4),
            color: Colors.black.withAlpha(30),
          ),
        ],
      ),
      child: child,
    );
  }
}

==> flx_ui-2.9.2.tar.gz: lib/widgets/deep_card/views/deep_card_view.dart <==
import 'package:flx_ui/flx_ui.dart';

class DeepCard extends StatelessWidget {
  final double? width;
  final double? height;

  final Color? color;

  final double? borderRadius;

  final bool clipped;

  final Widget? child;

  const DeepCard({
    Key? key,
    this.width,
    this.height,
    this.color,
    this.clipped = false,
    this.borderRadius,
    this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var inBorderRadius = (borderRadius ?? Metrics.borderRadius);
    var inColor = color ?? ColorTheme.primary(context);

    return clipped
        ? ClipRRect(
            borderRadius: BorderRadius.circular(inBorderRadius),
            child: _buildAll(inBorderRadius, inColor),
          )
        : _buildAll(inBorderRadius, inColor);
  }

  Container _buildAll(double inBorderRadius, Color inColor) {
    return Container(
      width: width,
      height: height,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(inBorderRadius),
        color: inColor,
        boxShadow: [
          BoxShadow(
            spreadRadius: -1,
            blurRadius: 3,
            color: Colors.black.withAlpha(50),
          ),
          BoxShadow(
            spreadRadius: -2,
            blurRadius: 5,
            color: Colors.black.withAlpha(20),
          ),
          BoxShadow(
            spreadRadius: -4,
            blurRadius: 8,
            offset: Offset(0, 4),
            color: Colors.black.withAlpha(30),
          ),
        ],
      ),
      child: child,
    );
  }
}
